@@ -1,9 +1,7 @@
 use super::component::LoggerComponent;
 use std::io::Error;
 
-pub struct ConsoleComponent {
-
-}
+pub struct ConsoleComponent {}
 
 impl ConsoleComponent {
     pub fn new() -> Self {
@@ -16,4 +14,4 @@ impl LoggerComponent for ConsoleComponent {
         println!("{}", msg);
         Ok(())
     }
-}
\ No newline at end of file
+}
