@@ -1,6 +1,6 @@
 use super::component::LoggerComponent;
 
-use std::fs::{File, OpenOptions};
+use std::fs::{create_dir, File, OpenOptions};
 use std::io::{Error, Write};
 use std::path::Path;
 
@@ -10,8 +10,18 @@ pub struct FileComponent {
 
 impl FileComponent {
     pub fn new(log_file_name: &str) -> Self {
+        if !Path::new("./log/").exists() {
+            if let Err(error) = create_dir(Path::new("./log/")) {
+                panic!("Failed to create directory for logger files output with error: {}", error);
+            }
+        }
+
         FileComponent {
-            file: match OpenOptions::new().create(true).append(true).open(Path::new(log_file_name)) {
+            file: match OpenOptions::new()
+                .create(true)
+                .append(true)
+                .open(Path::new(format!("./log/{}.log", log_file_name).as_str()))
+            {
                 Ok(value) => value,
                 Err(error) => {
                     panic!("Failed to open logger file due to error: {}", error);
